@@ -1,6 +1,6 @@
-""""A package which can convert videos, images, gifs, and even live video to ASCII art!"""
+"""A package which can convert videos, images, gifs, and even live video to ASCII art!"""
 
-__version__ = "4.0.0"
+__version__ = "4.0.1"
 
 from .image import ImageConverter
 from .video import VideoConverter
